#!/usr/bin/env bash
# script:  watch
# author:  Mike Smullin <mike@smullindesign.com>, Carlo Cancellieri <ccancellieri@gmail.com>
# license: GPLv3
# description:
#   watches the given path for changes
#   and executes a given command when changes occur
# usage:
#   watch <path> <cmd...>
#
path=$1
type sha1sum 2> /dev/null
if [ $? -eq 0 ]; then 
  shasum=sha1sum
else
  shasum=shasum
fi

shift
cmd=${*:1}
sha=0
update_sha() {
  #sha=`ls -lR --time-style=full-iso $path | $shasum`
  sha=`ls -lR $path | $shasum`
}
update_sha
previous_sha=$sha
build() {
  echo -en "\n running -> ${cmd[@]}\n\n"
  eval ${cmd[@]}
  echo -en "\n--> resumed watching."
}
compare() {
  update_sha
  if [[ $sha != $previous_sha ]] ; then
    echo -n "change detected,"
    build
    previous_sha=$sha
  else
    echo -n .
  fi
}
#trap build SIGINT
#trap exit SIGQUIT

#echo -e  "--> Press Ctrl+C to force build, Ctrl+\\ to exit."
build
echo -e  "--> Press Ctrl+C to exit."
echo -en "--> watching \"$path\"."
while true; do
  compare
  sleep 1
done
